@@ -1215,4 +1215,26 @@ class AnyButCJK(__Class):
         `CJK Unified Ideographs <https://en.wikipedia.org/wiki/CJK_Unified_Ideographs_(Unicode_block)>`_ \
         Unicode block.
         '''
-        super().__init__('[^\u4e00-\u9fd5]', is_negated=True)
\ No newline at end of file
+        super().__init__('[^\u4e00-\u9fd5]', is_negated=True)
+
+
+class AnyKoreanLetter(__Class):
+    '''
+    Matches any character from the Korean alphabet.
+    '''
+    def __init__(self) -> 'AnyKoreanLetter':
+        '''
+        Matches any character from the Korean alphabet.
+        '''
+        super().__init__('[\u3131-\u314e\uac00-\ud7a3]', is_negated=False)
+
+
+class AnyButKoreanLetter(__Class):
+    '''
+    Matches any character except for characters in the Koren alphabet.
+    '''
+    def __init__(self) -> 'AnyButKoreanLetter':
+        '''
+        Matches any character except for characters in the Korean alphabet.
+        '''
+        super().__init__('[^\u3131-\u314e\uac00-\ud7a3]', is_negated=True)
\ No newline at end of file
